@@ -21,8 +21,6 @@
 
 Q_LOGGING_CATEGORY(PLUGIN_TELEGRAM, "kf.purpose.plugins.telegram")
 
-EXPORT_SHARE_VERSION
-
 class TelegramJob : public Purpose::Job
 {
     Q_OBJECT
@@ -66,11 +64,13 @@ public:
         }
 
         QString exec = service->exec();
-        exec.replace(QLatin1String("-- @@u %u @@"), QLatin1String("-sendpath @@ %f @@"));
+        exec.replace(QLatin1String("%u"), QLatin1String("%f"));
+        exec.replace(QLatin1String("@@u"), QLatin1String("@@"));
+        exec.replace(QLatin1String(" -- "), QLatin1String(" -sendpath "));
         service->setExec(exec);
 
         auto *job = new KIO::ApplicationLauncherJob(service);
-        job->setUrls(arrayToList(data().value(QStringLiteral("urls")).toArray()));
+        job->setUrls(arrayToList(data().value(QLatin1String("urls")).toArray()));
         connect(job, &KIO::ApplicationLauncherJob::result, this, [this](KJob *job) {
             if (job->error()) {
                 qWarning() << "telegram share error:" << job->error() << job->errorString();
@@ -84,19 +84,13 @@ public:
         });
         job->start();
     }
-
-private:
 };
 
-class Q_DECL_EXPORT TelegramPlugin : public Purpose::PluginBase
+class TelegramPlugin : public Purpose::PluginBase
 {
     Q_OBJECT
 public:
-    TelegramPlugin(QObject *p, const QVariantList &)
-        : Purpose::PluginBase(p)
-    {
-    }
-
+    using PluginBase::PluginBase;
     Purpose::Job *createJob() const override
     {
         return new TelegramJob(nullptr);
